diff --git a/t3lib/class.t3lib_browsetree.php b/t3lib/class.t3lib_browsetree.php
index 39eb88c45c86fd6e454abd1620b00a1a46877cb8..b64098d78f7a7174d0c194e35cb4e911712f4e45 100644
--- a/t3lib/class.t3lib_browsetree.php
+++ b/t3lib/class.t3lib_browsetree.php
@@ -49,10 +49,11 @@ class t3lib_browseTree extends t3lib_treeView {
 	 * Initialize, setting what is necessary for browsing pages.
 	 * Using the current user.
 	 *
 	 * @param	string		Additional clause for selecting pages.
 	 * @return	void
 	 */
-	function init($clause = '') {
+	function init($clause = '', $orderByFields = '') {
 
 			// this will hide records from display - it has nothing todo with user rights!!
 		$clauseExludePidList = '';
@@ -49,10 +49,11 @@ class t3lib_browseTree extends t3lib_treeView {
 	 * Using the current user.
 	 *
-	 * @param	string		Additional clause for selecting pages.
-	 * @return	void
+	 * @param string $clause Additional clause for selecting pages.
+	 * @param string $orderByFields record ORDER BY field
+	 * @return void
 	 */
diff --git a/t3lib/class.t3lib_pagetree.php b/t3lib/class.t3lib_pagetree.php
index 6c51b405eb332ef1ba9258bc78dfba740985ec34..23d672547493471aa49e57d5fc346ca9b2ce8508 100644
--- a/t3lib/class.t3lib_pagetree.php
+++ b/t3lib/class.t3lib_pagetree.php
@@ -60,10 +60,11 @@ class t3lib_pageTree extends t3lib_treeView {
 	 * Init function
 	 * REMEMBER to feed a $clause which will filter out non-readable pages!
 	 *
 	 * @param	string		Part of where query which will filter out non-readable pages.
 	 * @return	void
 	 */
-	function init($clause = '') {
+	function init($clause = '', $orderByFields = '') {
 		parent::init(' AND deleted=0 ' . $clause, 'sorting');
 
 		if (t3lib_extMgm::isLoaded('cms')) {
@@ -60,10 +60,11 @@ class t3lib_pageTree extends t3lib_treeView {
 	 * REMEMBER to feed a $clause which will filter out non-readable pages!
 	 *
-	 * @param	string		Part of where query which will filter out non-readable pages.
-	 * @return	void
+	 * @param string $clause Part of where query which will filter out non-readable pages.
+	 * @param string $orderByFields record ORDER BY field
+	 * @return void
 	 */